@@ -618,4 +618,6 @@ class Function(TokenList):
         for t in parenthesis.tokens:
             if isinstance(t, IdentifierList):
                 return t.get_identifiers()
+            elif isinstance(t, Identifier):
+                return [t,]
         return []
