@@ -2,11 +2,15 @@
 
 """Tests sqlparse function."""
 
+import pytest
+
 from tests.utils import TestCaseBase
 
 import sqlparse
 import sqlparse.sql
 
+from sqlparse import tokens as T
+
 
 class SQLParseTest(TestCaseBase):
     """Tests sqlparse.parse()."""
@@ -107,6 +111,11 @@ class SQLParseTest(TestCaseBase):
         self.assertEqual(len(t), 1)
         self.assert_(isinstance(t[0], sqlparse.sql.Identifier))
 
+    def test_function_parameter(self):  # see issue94
+        t = sqlparse.parse('abs(some_col)')[0].tokens[0].get_parameters()
+        self.assertEqual(len(t), 1)
+        self.assert_(isinstance(t[0], sqlparse.sql.Identifier))
+
 
 def test_quoted_identifier():
     t = sqlparse.parse('select x.y as "z" from foo')[0].tokens
@@ -134,3 +143,10 @@ def test_psql_quotation_marks():  # issue83
           ....
     $PROC_2$ LANGUAGE plpgsql;""")
     assert len(t) == 2
+
+
+@pytest.mark.parametrize('ph', ['?', ':1', ':foo', '%s', '%(foo)s'])
+def test_placeholder(ph):
+    p = sqlparse.parse(ph)[0].tokens
+    assert len(p) == 1
+    assert p[0].ttype is T.Name.Placeholder
